@@ -10,16 +10,18 @@ class GitHubTests(BaseCase):
         # To avoid this automation blocker, two steps are being taken:
         # 1. self.slow_click() is being used to slow down Selenium actions.
         # 2. The browser's User Agent is modified to avoid Selenium-detection
-        #    when running in headless mode on Chrome.
-        if self.browser == "chrome" and self.headless:
+        #    when running in headless mode on Chrome or Edge (Chromium).
+        if self.headless and (
+                self.browser == "chrome" or self.browser == "edge"):
             self.driver.quit()
             self.get_new_driver(
                 agent="""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_14_4) """
                       """AppleWebKit/537.36 (KHTML, like Gecko) """
                       """Chrome/75.0.3770.100 Safari/537.36""")
         self.open("https://github.com/")
-        self.update_text("input.header-search-input", "SeleniumBase\n")
+        self.type("input.header-search-input", "SeleniumBase\n")
         self.slow_click('a[href="/seleniumbase/SeleniumBase"]')
+        self.click_if_visible('[data-action="click:signup-prompt#dismiss"]')
         self.assert_element("div.repository-content")
         self.assert_text("SeleniumBase", "h1")
         self.slow_click('a[title="seleniumbase"]')
