@@ -11,6 +11,6 @@ class GoogleTestClass(BaseCase):
     ])
     def test_parameterized_google_search(self, search_term, expected_text):
         self.open('https://google.com/ncr')
-        self.update_text('input[title="Search"]', search_term + '\n')
+        self.type('input[title="Search"]', search_term + '\n')
         self.assert_element('#result-stats')
         self.assert_text(expected_text, '#search')
