@@ -30,6 +30,7 @@ except (ImportError, ValueError):
     sb.headless = False
     sb.headed = False
     sb.start_page = None
+    sb.locale_code = None
     sb.servername = "localhost"
     sb.port = 4444
     sb.data = None
@@ -57,19 +58,21 @@ except (ImportError, ValueError):
     sb.save_screenshot_after_test = False
     sb.timeout_multiplier = None
     sb.pytest_html_report = None
-    sb.report_on = False
     sb.with_db_reporting = False
     sb.with_s3_logging = False
     sb.js_checking_on = False
+    sb.report_on = False
     sb.is_pytest = False
-    sb.time_limit = None
     sb.slow_mode = False
     sb.demo_mode = False
+    sb.time_limit = None
     sb.demo_sleep = 1
     sb.message_duration = 2
+    sb.block_images = False
     sb.settings_file = None
     sb.user_data_dir = None
     sb.proxy_string = None
+    sb.swiftshader = False
     sb.ad_block_on = False
     sb.highlights = None
     sb.check_js = False
