@@ -5,13 +5,13 @@ from seleniumbase import BaseCase
 
 class SwagLabsTests(BaseCase):
 
-    def login(self, username="standard_user"):
+    def login_to_swag_labs(self, username="standard_user"):
         """ Login to Swag Labs and verify that login was successful. """
         self.open("https://www.saucedemo.com/")
         if username not in self.get_text("#login_credentials"):
             self.fail("Invalid user for login: %s" % username)
-        self.update_text("#user-name", username)
-        self.update_text("#password", "secret_sauce")
+        self.type("#user-name", username)
+        self.type("#password", "secret_sauce")
         self.click('input[type="submit"]')
         self.assert_element("#inventory_container")
         self.assert_text("Products", "div.product_label")
@@ -24,7 +24,7 @@ class SwagLabsTests(BaseCase):
     def test_swag_labs_basic_functional_flow(self, username):
         """ This test checks functional flow of the Swag Labs store.
             This test is parameterized, and receives the user for login. """
-        self.login(username=username)
+        self.login_to_swag_labs(username=username)
 
         # Verify that the "Test.allTheThings() T-Shirt" appears on the page
         item_name = "Test.allTheThings() T-Shirt"
@@ -58,9 +58,9 @@ class SwagLabsTests(BaseCase):
         self.click("link=CHECKOUT")
         self.assert_exact_text("Checkout: Your Information", "div.subheader")
         self.assert_element("a.cart_cancel_link")
-        self.update_text("#first-name", "SeleniumBase")
-        self.update_text("#last-name", "Rocks")
-        self.update_text("#postal-code", "01720")
+        self.type("#first-name", "SeleniumBase")
+        self.type("#last-name", "Rocks")
+        self.type("#postal-code", "01720")
 
         # Checkout - Overview
         self.click("input.btn_primary")
@@ -73,7 +73,7 @@ class SwagLabsTests(BaseCase):
         # Finish Checkout and verify the item was removed from the cart
         self.click("link=FINISH")
         self.assert_exact_text("THANK YOU FOR YOUR ORDER", "h2")
-        self.assert_element("div.pony_express")
+        self.assert_element("img.pony_express")
         self.click("#shopping_cart_container path")
         self.assert_element_absent("div.inventory_item_name")
         self.click(continue_shopping_button)
@@ -87,5 +87,5 @@ class SwagLabsTests(BaseCase):
     def test_swag_labs_products_page_resource_verification(self, username):
         """ This test checks for 404 errors on the Swag Labs products page.
             This test is parameterized, and receives the user for login. """
-        self.login(username=username)
+        self.login_to_swag_labs(username=username)
         self.assert_no_404_errors()
