@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 from seleniumbase import BaseCase
 
 
@@ -7,13 +8,20 @@ class AppleTestClass(BaseCase):
         self.demo_mode = True
         self.demo_sleep = 0.5
         self.message_duration = 2.0
+        if self.headless and (
+                self.browser == "chrome" or self.browser == "edge"):
+            self.driver.quit()
+            self.get_new_driver(
+                agent="""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_14_4) """
+                      """AppleWebKit/537.36 (KHTML, like Gecko) """
+                      """Chrome/75.0.3770.100 Safari/537.36""")
         self.open("https://developer.apple.com/search/")
         title = "Testing with WebDriver in Safari"
-        self.update_text('[placeholder*="developer.apple.com"]', title + "\n")
+        self.type('[placeholder*="developer.apple.com"]', title + "\n")
         self.click("link=%s" % title)
-        self.assert_element('[href="/documentation"]')
+        self.assert_element('div.localnav-content [href*="/documentation/"]')
         self.assert_text(title, "h1")
-        self.highlight("div.topic-description p")
+        self.highlight("div.description div.abstract")
         self.highlight("h2")
         h3 = "h3:nth-of-type(%s)"
         self.assert_text("Make Sure You Have Safari’s WebDriver", h3 % "1")
