@@ -3,7 +3,7 @@
 # "sb" pytest fixture test in a method with no class
 def test_sb_fixture_with_no_class(sb):
     sb.open("https://google.com/ncr")
-    sb.update_text('input[title="Search"]', 'SeleniumBase\n')
+    sb.type('input[title="Search"]', 'SeleniumBase\n')
     sb.click('a[href*="github.com/seleniumbase/SeleniumBase"]')
     sb.click('a[title="seleniumbase"]')
 
@@ -12,6 +12,6 @@ def test_sb_fixture_with_no_class(sb):
 class Test_SB_Fixture():
     def test_sb_fixture_inside_class(self, sb):
         sb.open("https://google.com/ncr")
-        sb.update_text('input[title="Search"]', 'SeleniumBase\n')
+        sb.type('input[title="Search"]', 'SeleniumBase\n')
         sb.click('a[href*="github.com/seleniumbase/SeleniumBase"]')
         sb.click('a[title="examples"]')
