@@ -1,4 +1,4 @@
-''' NOTE: This test suite contains 2 passing tests and 2 failing tests. '''
+''' This test suite contains 2 passing tests and 2 failing tests. '''
 
 import pytest
 from seleniumbase import BaseCase
@@ -7,11 +7,11 @@ from seleniumbase import BaseCase
 class MyTestSuite(BaseCase):
 
     def test_1(self):
-        self.open("https://xkcd.com/1663/")
-        self.assert_text("Garden", "div#ctitle", timeout=3)
-        for p in range(4):
+        self.open("https://xkcd.com/1664/")
+        self.assert_text("Mycology", "div#ctitle", timeout=4)
+        for p in range(3):
             self.click('a[rel="next"]')
-        self.assert_text("Algorithms", "div#ctitle", timeout=3)
+        self.assert_text("Algorithms", "div#ctitle", timeout=4)
 
     @pytest.mark.expected_failure
     def test_2(self):
@@ -21,9 +21,9 @@ class MyTestSuite(BaseCase):
 
     def test_3(self):
         self.open("https://xkcd.com/1406/")
-        self.assert_text("Universal Converter Box", "div#ctitle", timeout=3)
+        self.assert_text("Universal Converter Box", "div#ctitle", timeout=4)
         self.open("https://xkcd.com/608/")
-        self.assert_text("Form", "div#ctitle", timeout=3)
+        self.assert_text("Form", "div#ctitle", timeout=4)
 
     @pytest.mark.expected_failure
     def test_4(self):
