@@ -8,11 +8,11 @@ class MijnTestklasse(Testgeval):
         self.openen("https://nl.wikipedia.org/wiki/Hoofdpagina")
         self.controleren_element('a[title*="hoofdpagina gaan"]')
         self.controleren_tekst("Welkom op Wikipedia", "td.hp-welkom")
-        self.tekst_bijwerken("#searchInput", "Stroopwafel")
+        self.typ("#searchInput", "Stroopwafel")
         self.klik("#searchButton")
         self.controleren_tekst("Stroopwafel", "#firstHeading")
         self.controleren_element('img[alt="Stroopwafels"]')
-        self.tekst_bijwerken("#searchInput", "Rijksmuseum Amsterdam")
+        self.typ("#searchInput", "Rijksmuseum Amsterdam")
         self.klik("#searchButton")
         self.controleren_tekst("Rijksmuseum", "#firstHeading")
         self.controleren_element('img[alt="Het Rijksmuseum"]')
