@@ -8,11 +8,11 @@ class MiaClasseDiTest(CasoDiProva):
         self.apri("https://it.wikipedia.org/wiki/")
         self.verificare_testo("Wikipedia")
         self.verificare_elemento('[title="Lingua italiana"]')
-        self.aggiornare_testo("#searchInput", "Pizza")
+        self.digitare("#searchInput", "Pizza")
         self.fare_clic("#searchButton")
         self.verificare_testo("Pizza", "#firstHeading")
-        self.verificare_elemento('img[alt*="Pizza"]')
-        self.aggiornare_testo("#searchInput", "Colosseo")
+        self.verificare_elemento('img[alt*="pizza"]')
+        self.digitare("#searchInput", "Colosseo")
         self.fare_clic("#searchButton")
         self.verificare_testo("Colosseo", "#firstHeading")
         self.verificare_elemento('img[alt*="Colosse"]')
