@@ -8,16 +8,17 @@ class MinhaClasseDeTeste(CasoDeTeste):
         self.abrir("https://pt.wikipedia.org/wiki/")
         self.verificar_texto("Wikipédia")
         self.verificar_elemento('[title="Língua portuguesa"]')
-        self.atualizar_texto("#searchInput", "João Pessoa")
+        self.tipo("#searchInput", "João Pessoa")
         self.clique("#searchButton")
         self.verificar_texto("João Pessoa", "#firstHeading")
         self.verificar_elemento('img[alt*="João Pessoa"]')
-        self.atualizar_texto("#searchInput", "Florianópolis")
+        self.tipo("#searchInput", "Florianópolis")
         self.clique("#searchButton")
         self.verificar_texto("Florianópolis", "h1#firstHeading")
         self.verificar_elemento('img[alt*="Avenida Beira Mar"]')
         self.voltar()
         self.verificar_verdade("João" in self.obter_url_atual())
-        self.atualizar_texto("#searchInput", "Moqueca\n")
-        self.verificar_texto("Moqueca", "#firstHeading")
-        self.verificar_texto_do_link("Culinária do Brasil")
+        self.tipo("#searchInput", "Teatro Amazonas")
+        self.clique("#searchButton")
+        self.verificar_texto("Teatro Amazonas", "#firstHeading")
+        self.verificar_texto_do_link("Festival Amazonas de Ópera")
