@@ -8,11 +8,11 @@ class МойТестовыйКласс(ТестНаСелен):
         self.открыть("https://ru.wikipedia.org/wiki/")
         self.подтвердить_элемент('[title="Русский язык"]')
         self.подтвердить_текст("Википедия", "h2.main-wikimedia-header")
-        self.обновить_текст("#searchInput", "МГУ")
+        self.введите("#searchInput", "МГУ")
         self.нажмите("#searchButton")
         self.подтвердить_текст("университет", "#firstHeading")
         self.подтвердить_элемент('img[alt="МГУ, вид с воздуха.jpg"]')
-        self.обновить_текст("#searchInput", "приключения Шурика")
+        self.введите("#searchInput", "приключения Шурика")
         self.нажмите("#searchButton")
         self.подтвердить_текст("Операция «Ы» и другие приключения Шурика")
         self.подтвердить_элемент('img[alt="Постер фильма"]')
