@@ -7,12 +7,12 @@ class MiClaseDePrueba(CasoDePrueba):
     def test_ejemplo_1(self):
         self.abrir("https://es.wikipedia.org/wiki/")
         self.verificar_texto("Wikipedia")
-        self.verificar_elemento('[title="Visitar la página principal"]')
-        self.actualizar_texto("#searchInput", "Parc d'Atraccions Tibidabo")
+        self.verificar_elemento('[title*="la página principal"]')
+        self.escriba("#searchInput", "Parc d'Atraccions Tibidabo")
         self.haga_clic("#searchButton")
         self.verificar_texto("Tibidabo", "#firstHeading")
         self.verificar_elemento('img[alt*="Tibidabo"]')
-        self.actualizar_texto("#searchInput", "Palma de Mallorca")
+        self.escriba("#searchInput", "Palma de Mallorca")
         self.haga_clic("#searchButton")
         self.verificar_texto("Palma de Mallorca", "#firstHeading")
         self.verificar_elemento('img[alt*="Palma"]')
