@@ -13,11 +13,11 @@ Example:
         seleniumbase install chromedriver
         seleniumbase install geckodriver
         seleniumbase install edgedriver
-        seleniumbase install chromedriver 81.0.4044.69
+        seleniumbase install chromedriver 84.0.4147.30
         seleniumbase install chromedriver latest
         seleniumbase install chromedriver -p
         seleniumbase install chromedriver latest -p
-        seleniumbase install edgedriver 79.0.309.65
+        seleniumbase install edgedriver 84.0.522.61
 Output:
         Installs the chosen webdriver to seleniumbase/drivers/
         (chromedriver is required for Chrome automation)
@@ -40,9 +40,9 @@ urllib3.disable_warnings()
 DRIVER_DIR = os.path.dirname(os.path.realpath(drivers.__file__))
 LOCAL_PATH = "/usr/local/bin/"  # On Mac and Linux systems
 DEFAULT_CHROMEDRIVER_VERSION = "2.44"
-DEFAULT_GECKODRIVER_VERSION = "v0.26.0"
-DEFAULT_EDGEDRIVER_VERSION = "79.0.309.65"
-DEFAULT_OPERADRIVER_VERSION = "v.81.0.4044.113"
+DEFAULT_GECKODRIVER_VERSION = "v0.27.0"
+DEFAULT_EDGEDRIVER_VERSION = "84.0.522.61"
+DEFAULT_OPERADRIVER_VERSION = "v.84.0.4147.89"
 
 
 def invalid_run_command():
@@ -91,7 +91,9 @@ def main(override=None):
 
     num_args = len(sys.argv)
     if sys.argv[0].split('/')[-1].lower() == "seleniumbase" or (
-            sys.argv[0].split('\\')[-1].lower() == "seleniumbase"):
+            sys.argv[0].split('\\')[-1].lower() == "seleniumbase") or (
+            sys.argv[0].split('/')[-1].lower() == "sbase") or (
+            sys.argv[0].split('\\')[-1].lower() == "sbase"):
         if num_args < 3 or num_args > 5:
             invalid_run_command()
     else:
