@@ -1,4 +1,6 @@
+# -*- coding: utf-8 -*-
 import codecs
+import datetime
 import os
 import shutil
 import sys
@@ -33,28 +35,79 @@ def log_test_failure_data(test, test_logpath, driver, browser, url=None):
         last_page = url
     else:
         last_page = get_last_page(driver)
+    timestamp = str(int(time.time())) + "  (Unix Timestamp)"
+    now = datetime.datetime.now()
+    utc_offset = -time.timezone / 3600.0
+    utc_str = "UTC+0"
+    if utc_offset > 0:
+        if utc_offset < 10:
+            utc_str = "UTC+0%s" % utc_offset
+        else:
+            utc_str = "UTC+%s" % utc_offset
+    elif utc_offset < 0:
+        if utc_offset > -10:
+            utc_str = "UTC-0%s" % abs(utc_offset)
+        else:
+            utc_str = "UTC-%s" % abs(utc_offset)
+    utc_str = utc_str.replace('.5', '.3').replace('.', ':') + "0"
+    time_zone = ""
+    try:
+        time_zone = '(' + time.tzname[time.daylight] + ', ' + utc_str + ')'
+    except Exception:
+        time_zone = '(' + utc_str + ')'
+    # Use [Day-of-Week, Month Day, Year] format when time zone < GMT/UTC-3
+    the_date = now.strftime("%A, %B %d, %Y").replace(' 0', ' ')
+    if utc_offset >= -3:
+        # Use [Day-of-Week, Day Month Year] format when time zone >= GMT/UTC-3
+        the_date = now.strftime("%A, %d %B %Y").replace(' 0', ' ')
+    the_time = now.strftime("%I:%M:%S %p  ") + time_zone
+    if the_time.startswith("0"):
+        the_time = the_time[1:]
+    test_id = get_test_id(test)
     data_to_save = []
+    data_to_save.append("%s" % test_id)
+    data_to_save.append("----------------------------------------------------")
     data_to_save.append("Last Page: %s" % last_page)
     data_to_save.append("  Browser: %s" % browser)
-    data_to_save.append("Timestamp: %s" % int(time.time()))
-    if sys.version_info[0] >= 3 and hasattr(test, '_outcome'):
-        if test._outcome.errors:
-            try:
-                exc_message = test._outcome.errors[0][1][1]
-                traceback_address = test._outcome.errors[0][1][2]
-                traceback_list = traceback.format_list(
-                    traceback.extract_tb(traceback_address)[1:])
-                traceback_message = ''.join(traceback_list).strip()
-            except Exception:
-                exc_message = "(Unknown Exception)"
-                traceback_message = "(Unknown Traceback)"
-            data_to_save.append("Traceback: " + traceback_message)
-            data_to_save.append("Exception: " + str(exc_message))
+    data_to_save.append("Timestamp: %s" % timestamp)
+    data_to_save.append("     Date: %s" % the_date)
+    data_to_save.append("     Time: %s" % the_time)
+    data_to_save.append("----------------------------------------------------")
+    if sys.version_info[0] >= 3 and hasattr(test, '_outcome') and (
+            hasattr(test._outcome, 'errors') and test._outcome.errors):
+        try:
+            exc_message = test._outcome.errors[0][1][1]
+            traceback_address = test._outcome.errors[0][1][2]
+            traceback_list = traceback.format_list(
+                traceback.extract_tb(traceback_address)[1:])
+            traceback_message = ''.join(traceback_list).strip()
+        except Exception:
+            exc_message = "(Unknown Exception)"
+            traceback_message = "(Unknown Traceback)"
+        data_to_save.append("Traceback: " + traceback_message)
+        data_to_save.append("Exception: " + str(exc_message))
     else:
-        data_to_save.append("Traceback: " + ''.join(
+        the_traceback = None
+        the_traceback = ''.join(
             traceback.format_exception(sys.exc_info()[0],
                                        sys.exc_info()[1],
-                                       sys.exc_info()[2])))
+                                       sys.exc_info()[2]))
+        if not the_traceback or len(str(the_traceback)) < 30 or (
+                the_traceback.endswith("StopIteration\n")):
+            good_stack = []
+            the_stacks = traceback.format_list(
+                traceback.extract_tb(sys.last_traceback))
+            for stack in the_stacks:
+                if "/site-packages/pluggy/" not in stack:
+                    if "/site-packages/_pytest/" not in stack:
+                        good_stack.append(stack)
+            the_traceback = ''.join(good_stack)
+            data_to_save.append("Traceback: " + the_traceback)
+            last_value = sys.last_value
+            if last_value:
+                data_to_save.append("Exception: " + str(last_value))
+        else:
+            data_to_save.append("Traceback: " + the_traceback)
     log_file.writelines("\r\n".join(data_to_save))
     log_file.close()
 
@@ -76,6 +129,16 @@ def log_page_source(test_logpath, driver, source=None):
     html_file.close()
 
 
+def get_test_id(test):
+    test_id = "%s.%s.%s" % (
+        test.__class__.__module__,
+        test.__class__.__name__,
+        test._testMethodName)
+    if test._sb_test_identifier and len(str(test._sb_test_identifier)) > 6:
+        test_id = test._sb_test_identifier
+    return test_id
+
+
 def get_last_page(driver):
     try:
         last_page = driver.current_url
