@@ -23,7 +23,6 @@ import codecs
 import os
 import sys
 import time
-import traceback
 from selenium.common.exceptions import StaleElementReferenceException
 from selenium.common import exceptions as selenium_exceptions
 from selenium.webdriver.common.by import By
@@ -36,7 +35,7 @@ from selenium.webdriver.remote.errorhandler import NoSuchWindowException
 from seleniumbase.config import settings
 from seleniumbase.core import log_helper
 from seleniumbase.fixtures import page_utils
-from seleniumbase.fixtures import shared_utils
+from seleniumbase.fixtures import shared_utils as s_utils
 ENI_Exception = selenium_exceptions.ElementNotInteractableException
 
 
@@ -113,32 +112,9 @@ def hover_element(driver, element):
     hover.perform()
 
 
-def format_message(exception, message):
-    """
-    Formats an exception message to make the output cleaner.
-    """
-    if exception == Exception:
-        pass
-    elif exception == ElementNotVisibleException:
-        message = "ElementNotVisibleException: %s" % message
-    elif exception == NoSuchElementException:
-        message = "NoSuchElementException: %s" % message
-    elif exception == NoAlertPresentException:
-        message = "NoAlertPresentException: %s" % message
-    elif exception == NoSuchFrameException:
-        message = "NoSuchFrameException: %s" % message
-    elif exception == NoSuchWindowException:
-        message = "NoSuchWindowException: %s" % message
-    elif type(exception) is str:
-        message = "%s: %s" % (exception, message)
-    else:
-        pass
-    return message
-
-
 def timeout_exception(exception, message):
-    message = format_message(exception, message)
-    raise Exception(message)
+    exc, message = s_utils.format_exc(exception, message)
+    raise exc(message)
 
 
 def hover_and_click(driver, hover_selector, click_selector,
@@ -241,9 +217,9 @@ def wait_for_element_present(driver, selector, by=By.CSS_SELECTOR,
                              timeout=settings.LARGE_TIMEOUT):
     """
     Searches for the specified element by the given selector. Returns the
-    element object if the element is present on the page. The element can be
-    invisible. Raises an exception if the element does not appear in the
-    specified timeout.
+    element object if it exists in the HTML. (The element can be invisible.)
+    Raises NoSuchElementException if the element does not exist in the HTML
+    within the specified timeout.
     @Params
     driver - the webdriver object
     selector - the locator for identifying the page element (required)
@@ -256,7 +232,7 @@ def wait_for_element_present(driver, selector, by=By.CSS_SELECTOR,
     start_ms = time.time() * 1000.0
     stop_ms = start_ms + (timeout * 1000.0)
     for x in range(int(timeout * 10)):
-        shared_utils.check_if_time_limit_exceeded()
+        s_utils.check_if_time_limit_exceeded()
         try:
             element = driver.find_element(by=by, value=selector)
             return element
@@ -280,24 +256,27 @@ def wait_for_element_visible(driver, selector, by=By.CSS_SELECTOR,
     """
     Searches for the specified element by the given selector. Returns the
     element object if the element is present and visible on the page.
-    Raises an exception if the element does not appear in the
-    specified timeout.
+    Raises NoSuchElementException if the element does not exist in the HTML
+    within the specified timeout.
+    Raises ElementNotVisibleException if the element exists in the HTML,
+    but is not visible (eg. opacity is "0") within the specified timeout.
     @Params
     driver - the webdriver object (required)
     selector - the locator for identifying the page element (required)
     by - the type of selector being used (Default: By.CSS_SELECTOR)
     timeout - the time to wait for elements in seconds
-
     @Returns
     A web element object
     """
     element = None
+    is_present = False
     start_ms = time.time() * 1000.0
     stop_ms = start_ms + (timeout * 1000.0)
     for x in range(int(timeout * 10)):
-        shared_utils.check_if_time_limit_exceeded()
+        s_utils.check_if_time_limit_exceeded()
         try:
             element = driver.find_element(by=by, value=selector)
+            is_present = True
             if element.is_displayed():
                 return element
             else:
@@ -312,6 +291,13 @@ def wait_for_element_visible(driver, selector, by=By.CSS_SELECTOR,
     if timeout == 1:
         plural = ""
     if not element and by != By.LINK_TEXT:
+        if not is_present:
+            # The element does not exist in the HTML
+            message = (
+                "Element {%s} was not present after %s second%s!"
+                "" % (selector, timeout, plural))
+            timeout_exception(NoSuchElementException, message)
+        # The element exists in the HTML, but is not visible
         message = (
             "Element {%s} was not visible after %s second%s!"
             "" % (selector, timeout, plural))
@@ -328,8 +314,11 @@ def wait_for_text_visible(driver, text, selector, by=By.CSS_SELECTOR,
     """
     Searches for the specified element by the given selector. Returns the
     element object if the text is present in the element and visible
-    on the page. Raises an exception if the text or element do not appear
-    in the specified timeout.
+    on the page.
+    Raises NoSuchElementException if the element does not exist in the HTML
+    within the specified timeout.
+    Raises ElementNotVisibleException if the element exists in the HTML,
+    but the text is not visible within the specified timeout.
     @Params
     driver - the webdriver object (required)
     text - the text that is being searched for in the element (required)
@@ -340,12 +329,14 @@ def wait_for_text_visible(driver, text, selector, by=By.CSS_SELECTOR,
     A web element object that contains the text searched for
     """
     element = None
+    is_present = False
     start_ms = time.time() * 1000.0
     stop_ms = start_ms + (timeout * 1000.0)
     for x in range(int(timeout * 10)):
-        shared_utils.check_if_time_limit_exceeded()
+        s_utils.check_if_time_limit_exceeded()
         try:
             element = driver.find_element(by=by, value=selector)
+            is_present = True
             if element.is_displayed() and text in element.text:
                 return element
             else:
@@ -360,6 +351,13 @@ def wait_for_text_visible(driver, text, selector, by=By.CSS_SELECTOR,
     if timeout == 1:
         plural = ""
     if not element:
+        if not is_present:
+            # The element does not exist in the HTML
+            message = (
+                "Element {%s} was not present after %s second%s!"
+                "" % (selector, timeout, plural))
+            timeout_exception(NoSuchElementException, message)
+        # The element exists in the HTML, but the text is not visible
         message = (
             "Expected text {%s} for {%s} was not visible after %s second%s!"
             "" % (text, selector, timeout, plural))
@@ -372,8 +370,10 @@ def wait_for_exact_text_visible(driver, text, selector, by=By.CSS_SELECTOR,
     Searches for the specified element by the given selector. Returns the
     element object if the text matches exactly with the text in the element,
     and the text is visible.
-    Raises an exception if the text or element do not appear
-    in the specified timeout.
+    Raises NoSuchElementException if the element does not exist in the HTML
+    within the specified timeout.
+    Raises ElementNotVisibleException if the element exists in the HTML,
+    but the exact text is not visible within the specified timeout.
     @Params
     driver - the webdriver object (required)
     text - the exact text that is expected for the element (required)
@@ -384,12 +384,14 @@ def wait_for_exact_text_visible(driver, text, selector, by=By.CSS_SELECTOR,
     A web element object that contains the text searched for
     """
     element = None
+    is_present = False
     start_ms = time.time() * 1000.0
     stop_ms = start_ms + (timeout * 1000.0)
     for x in range(int(timeout * 10)):
-        shared_utils.check_if_time_limit_exceeded()
+        s_utils.check_if_time_limit_exceeded()
         try:
             element = driver.find_element(by=by, value=selector)
+            is_present = True
             if element.is_displayed() and text.strip() == element.text.strip():
                 return element
             else:
@@ -404,6 +406,13 @@ def wait_for_exact_text_visible(driver, text, selector, by=By.CSS_SELECTOR,
     if timeout == 1:
         plural = ""
     if not element:
+        if not is_present:
+            # The element does not exist in the HTML
+            message = (
+                "Element {%s} was not present after %s second%s!"
+                "" % (selector, timeout, plural))
+            timeout_exception(NoSuchElementException, message)
+        # The element exists in the HTML, but the exact text is not visible
         message = (
             "Expected exact text {%s} for {%s} was not visible "
             "after %s second%s!" % (text, selector, timeout, plural))
@@ -425,7 +434,7 @@ def wait_for_element_absent(driver, selector, by=By.CSS_SELECTOR,
     start_ms = time.time() * 1000.0
     stop_ms = start_ms + (timeout * 1000.0)
     for x in range(int(timeout * 10)):
-        shared_utils.check_if_time_limit_exceeded()
+        s_utils.check_if_time_limit_exceeded()
         try:
             driver.find_element(by=by, value=selector)
             now_ms = time.time() * 1000.0
@@ -458,7 +467,7 @@ def wait_for_element_not_visible(driver, selector, by=By.CSS_SELECTOR,
     start_ms = time.time() * 1000.0
     stop_ms = start_ms + (timeout * 1000.0)
     for x in range(int(timeout * 10)):
-        shared_utils.check_if_time_limit_exceeded()
+        s_utils.check_if_time_limit_exceeded()
         try:
             element = driver.find_element(by=by, value=selector)
             if element.is_displayed():
@@ -497,7 +506,7 @@ def wait_for_text_not_visible(driver, text, selector, by=By.CSS_SELECTOR,
     start_ms = time.time() * 1000.0
     stop_ms = start_ms + (timeout * 1000.0)
     for x in range(int(timeout * 10)):
-        shared_utils.check_if_time_limit_exceeded()
+        s_utils.check_if_time_limit_exceeded()
         if not is_text_visible(driver, text, selector, by=by):
             return True
         now_ms = time.time() * 1000.0
@@ -605,6 +614,7 @@ def save_test_failure_data(driver, name, browser_type, folder=None):
     Saves failure data to the current directory (or to a subfolder if provided)
     If the folder provided doesn't exist, it will get created.
     """
+    import traceback
     if folder:
         abs_path = os.path.abspath('.')
         file_path = abs_path + "/%s" % folder
@@ -664,7 +674,7 @@ def wait_for_and_switch_to_alert(driver, timeout=settings.LARGE_TIMEOUT):
     start_ms = time.time() * 1000.0
     stop_ms = start_ms + (timeout * 1000.0)
     for x in range(int(timeout * 10)):
-        shared_utils.check_if_time_limit_exceeded()
+        s_utils.check_if_time_limit_exceeded()
         try:
             alert = driver.switch_to.alert
             # Raises exception if no alert present
@@ -692,7 +702,7 @@ def switch_to_frame(driver, frame, timeout=settings.SMALL_TIMEOUT):
     start_ms = time.time() * 1000.0
     stop_ms = start_ms + (timeout * 1000.0)
     for x in range(int(timeout * 10)):
-        shared_utils.check_if_time_limit_exceeded()
+        s_utils.check_if_time_limit_exceeded()
         try:
             driver.switch_to.frame(frame)
             return True
@@ -736,7 +746,7 @@ def switch_to_window(driver, window, timeout=settings.SMALL_TIMEOUT):
     stop_ms = start_ms + (timeout * 1000.0)
     if isinstance(window, int):
         for x in range(int(timeout * 10)):
-            shared_utils.check_if_time_limit_exceeded()
+            s_utils.check_if_time_limit_exceeded()
             try:
                 window_handle = driver.window_handles[window]
                 driver.switch_to.window(window_handle)
@@ -756,7 +766,7 @@ def switch_to_window(driver, window, timeout=settings.SMALL_TIMEOUT):
     else:
         window_handle = window
         for x in range(int(timeout * 10)):
-            shared_utils.check_if_time_limit_exceeded()
+            s_utils.check_if_time_limit_exceeded()
             try:
                 driver.switch_to.window(window_handle)
                 return True
