@@ -106,7 +106,10 @@ def is_valid_url(url):
         r'\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3})'  # ...or ip
         r'(?::\d+)?'  # optional port
         r'(?:/?|[/?]\S+)$', re.IGNORECASE)
-    if regex.match(url) or url == 'about:blank' or url == 'data:,':
+    if regex.match(url) or ((url.startswith("about:") or (
+            url.startswith("data:") or url.startswith("chrome:") or (
+            url.startswith("edge:") or url.startswith("opera:") or (
+            url.startswith("file:")))))):
         return True
     else:
         return False
@@ -215,7 +218,8 @@ def _download_file_to(file_url, destination_folder, new_file_name=None):
 
 
 def _save_data_as(data, destination_folder, file_name):
-    out_file = codecs.open(destination_folder + '/' + file_name, "w+")
+    out_file = codecs.open(
+        destination_folder + '/' + file_name, "w+", encoding="utf-8")
     out_file.writelines(data)
     out_file.close()
 
