@@ -38,7 +38,9 @@ def main():
     dir_path = os.path.dirname(os.path.realpath(__file__))
     num_args = len(sys.argv)
     if sys.argv[0].split('/')[-1] == "seleniumbase" or (
-            sys.argv[0].split('\\')[-1] == "seleniumbase"):
+            sys.argv[0].split('\\')[-1] == "seleniumbase") or (
+            sys.argv[0].split('/')[-1] == "sbase") or (
+            sys.argv[0].split('\\')[-1] == "sbase"):
         if num_args < 3:
             invalid_run_command()
     else:
@@ -79,7 +81,7 @@ def main():
         if grid_hub_command == "start" or grid_hub_command == "restart":
             shell_command = (
                 """java -jar %s/selenium-server-standalone.jar -role hub """
-                """-timeout 180 -browserTimeout 75 -port 4444""" % dir_path)
+                """-timeout 230 -browserTimeout 170 -port 4444""" % dir_path)
             print("\nStarting Selenium-WebDriver Grid Hub...\n")
             print(shell_command)
             print("")
